Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(937)

Unified Diff: talk/media/base/mediachannel.h

Issue 1668493002: Replace uses of cricket::VideoRenderer by rtc::VideoSinkInterface. (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « talk/media/base/fakemediaengine.h ('k') | talk/media/base/videoengine_unittest.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: talk/media/base/mediachannel.h
diff --git a/talk/media/base/mediachannel.h b/talk/media/base/mediachannel.h
index dfd3be9010948ac78078d7979217db56a537f189..b72af4d904f291ab25a9c9a92cd95a5dfcd05235 100644
--- a/talk/media/base/mediachannel.h
+++ b/talk/media/base/mediachannel.h
@@ -42,6 +42,7 @@
#include "webrtc/base/sigslot.h"
#include "webrtc/base/socket.h"
#include "webrtc/base/window.h"
+#include "webrtc/media/base/videosinkinterface.h"
// TODO(juberti): re-evaluate this include
#include "talk/session/media/audiomonitor.h"
@@ -60,7 +61,7 @@ namespace cricket {
class AudioRenderer;
class ScreencastId;
class VideoCapturer;
-class VideoRenderer;
+class VideoFrame;
struct RtpHeader;
struct VideoFormat;
@@ -982,7 +983,7 @@ class VideoMediaChannel : public MediaChannel {
ERROR_PLAY_SRTP_REPLAY, // Packet replay detected.
};
- VideoMediaChannel() : renderer_(NULL) {}
+ VideoMediaChannel() {}
virtual ~VideoMediaChannel() {}
virtual bool SetSendParameters(const VideoSendParameters& params) = 0;
@@ -995,17 +996,15 @@ class VideoMediaChannel : public MediaChannel {
virtual bool SetVideoSend(uint32_t ssrc,
bool enable,
const VideoOptions* options) = 0;
// Sets the renderer object to be used for the specified stream.
// If SSRC is 0, the renderer is used for the 'default' stream.
- virtual bool SetRenderer(uint32_t ssrc, VideoRenderer* renderer) = 0;
+ virtual bool SetSink(uint32_t ssrc,
+ rtc::VideoSinkInterface<cricket::VideoFrame>* sink) = 0;
// If |ssrc| is 0, replace the default capturer (engine capturer) with
// |capturer|. If |ssrc| is non zero create a new stream with |ssrc| as SSRC.
virtual bool SetCapturer(uint32_t ssrc, VideoCapturer* capturer) = 0;
// Gets quality stats for the channel.
virtual bool GetStats(VideoMediaInfo* info) = 0;
-
- protected:
- VideoRenderer *renderer_;
};
enum DataMessageType {
« no previous file with comments | « talk/media/base/fakemediaengine.h ('k') | talk/media/base/videoengine_unittest.h » ('j') | no next file with comments »
@@ -995,17 +996,15 @@ class VideoMediaChannel : public MediaChannel {
bool enable,
const VideoOptions* options) = 0;
- // Sets the renderer object to be used for the specified stream.
+ // Sets the sink object to be used for the specified stream.
// If SSRC is 0, the renderer is used for the 'default' stream.

Powered by Google App Engine
This is Rietveld 408576698